@@ -37,9 +37,6 @@ use Socket;
 use POSIX;
 use Sys::Hostname;
 #eval "use Net::SSLeay";
-
-# add /Library/QuickTimeStreaming/AdminHtml to INC so that it can find SSLeay.bundle
-push(@INC, "/Library/QuickTimeStreaming/AdminHtml");
 if ($^O eq "darwin")
 {
      eval "require '/Library/QuickTimeStreaming/AdminHtml/SSLeay.pl'";
@@ -1403,10 +1400,7 @@ sub handle_request
 	    	$doing_eval = 0;
 	    	if ($@) {
 				# Error in perl!
-				# Uncomment the first line (and comment the second) for debug
-				# Error message has security implications.
-				#&http_error(500, "Perl execution failed", $@);
-				&http_error(500, "Perl execution failed");
+				&http_error(500, "Perl execution failed", $@);
 	    	}
 	    	elsif (!$doneheaders) {
 				&http_error(500, "Missing Header");
